==> mandelbulber2_2.09.3.orig.tar.gz: mandelbulber2-2.09-3/qt/material_editor.h <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016 Krzysztof Marczak        §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * cMaterialEditor - promoted QWidget for editing of a material
 */

#ifndef MANDELBULBER2_QT_MATERIAL_EDITOR_H_
#define MANDELBULBER2_QT_MATERIAL_EDITOR_H_

#include <QWidget>

#include "../src/automated_widgets.hpp"
#include "../src/color_palette.hpp"
#include "../src/parameters.hpp"

namespace Ui
{
class cMaterialEditor;
}

class cMaterialEditor : public QWidget
{
	Q_OBJECT

public:
	explicit cMaterialEditor(QWidget *parent = NULL);
	~cMaterialEditor();
	void AssignMaterial(cParameterContainer *params, int index);

private slots:
	void slotPressedButtonNewRandomPalette();
	void slotPressedButtonGetPaletteFromImage();
	void slotPressedButtonRandomize();
	void slotChangedSpinBoxPaletteOffset(double value);
	void slotChangedSpinBoxPaletteSize(int value);
	void slotChangedComboFractalColoringAlgorithm(int index);

private:
	void ConnectSignals(void);
	cColorPalette GetPaletteFromImage(const QString &filename);

	Ui::cMaterialEditor *ui;
	int materialIndex;
	cParameterContainer *parameterContainer;
	bool isMaterialAssigned;

	cAutomatedWidgets *automatedWidgets;

signals:
	void materialChanged(int matIndex);
};

#endif /* MANDELBULBER2_QT_MATERIAL_EDITOR_H_ */

==> mandelbulber2_2.10.orig.tar.gz: mandelbulber2-2.10/qt/material_editor.h <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * cMaterialEditor - promoted QWidget for editing of a material
 */

#ifndef MANDELBULBER2_QT_MATERIAL_EDITOR_H_
#define MANDELBULBER2_QT_MATERIAL_EDITOR_H_

#include <QWidget>

#include "../src/color_palette.hpp"

// forward declarations
class cAutomatedWidgets;
class cParameterContainer;

namespace Ui
{
class cMaterialEditor;
}

class cMaterialEditor : public QWidget
{
	Q_OBJECT

public:
	explicit cMaterialEditor(QWidget *parent = nullptr);
	~cMaterialEditor();
	void AssignMaterial(cParameterContainer *params, int index);

private slots:
	void slotPressedButtonNewRandomPalette() const;
	void slotPressedButtonGetPaletteFromImage();
	void slotPressedButtonRandomize() const;
	void slotChangedSpinBoxPaletteOffset(double value) const;
	void slotChangedSpinBoxPaletteSize(int value) const;
	void slotChangedComboFractalColoringAlgorithm(int index) const;

private:
	void ConnectSignals();
	cColorPalette GetPaletteFromImage(const QString &filename) const;

	Ui::cMaterialEditor *ui;
	int materialIndex;
	cParameterContainer *parameterContainer;
	bool isMaterialAssigned;

	cAutomatedWidgets *automatedWidgets;

signals:
	void materialChanged(int matIndex);
};

#endif /* MANDELBULBER2_QT_MATERIAL_EDITOR_H_ */
